.. crabnet documentation master file, created by
   sphinx-quickstart on Fri Nov  5 01:44:19 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to CrabNet!
===================

This is the documentation for `crabnet <https://github.com/sparks-baird/crabnet>`_.
Compositionally-restricted attention-based Network (CrabNet) is a
composition-based regression and classification algorithm for materials properties.
CrabNet leverages a transformer architecture inspired by recent advances in natural
language processing to learn chemical relationships and improve property prediction.
CrabNet was originally proposed by Wang, Kauwe, Murdock, and Sparks (`npj Computational
Materials <https://dx.doi.org/10.1038/s41524-021-00545-1>`_, `ChemRxiv
<https://dx.doi.org/10.26434/chemrxiv.11869026.v3>`_). The
library :code:`crabnet` provides a GPU-accelerated (and CPU-compatible) Python
implementation. :code:`crabnet` will regress or classify materials properties for a custom training dataset of chemical formula and target
properties in just a few lines of code! `Get started learning about CrabNet <https://crabnet.readthedocs.io/en/latest/readme.html>`_.

.. raw:: html

   <a class="github-button" href="https://github.com/anthony-wang/crabnet"
   data-icon="octicon-star" data-size="large" data-show-count="true" aria-label="Star
   anthony-wang/crabnet on GitHub">(Original Repo) Star</a>
   <a class="github-button"
   href="https://github.com/sgbaird" data-size="large" data-show-count="true"
   aria-label="Follow @sgbaird on GitHub">Follow @sgbaird</a>
   <a class="github-button" href="https://github.com/sparks-baird/crabnet/issues"
   data-icon="octicon-issue-opened" data-size="large" data-show-count="true"
   aria-label="Issue sparks-baird/crabnet on GitHub">Issue</a>
   <a class="github-button" href="https://github.com/sparks-baird/crabnet/discussions" data-icon="octicon-comment-discussion" data-size="large" aria-label="Discuss sparks-baird/crabnet on GitHub">Discuss</a>
   <br><br>

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   examples
   figures
   crabnet

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. raw:: html

   <script async defer src="https://buttons.github.io/buttons.js"></script>
